from box.functools import Decorator


class mixin(Decorator):

    # Public

    decorator = '_clyde_mixin_mixin'

    def __init__(self, require=None):
        self.__require = require

    def __call__(self, function):
        setattr(function, self.decorator, self)
        return function

    @property
    def require(self):
        return self.__require
